import sys
import re

def add_sequence_numbers(input_file, output_file):
    """자막 파일의 시간 구간 위에만 순서 코드를 추가하고 결과를 다른 파일에 저장합니다."""
    try:
        with open(input_file, 'r', encoding='utf-8') as infile, open(output_file, 'w', encoding='utf-8') as outfile:
            lines = infile.readlines()
            line_number = 1
            for line in lines:
                if re.match(r'\d{2}:\d{2}:\d{2},\d{3} --> \d{2}:\d{2}:\d{2},\d{3}', line.strip()):
                    outfile.write(f"{line_number}\n{line}")
                    line_number += 1
                else:
                    outfile.write(line)
        print(f"'{input_file}' 파일에 순서 코드를 추가하고 '{output_file}' 파일에 저장했습니다.")
    except FileNotFoundError:
        print(f"오류: '{input_file}' 파일을 찾을 수 없습니다.")
    except Exception as e:
        print(f"오류: {e}")

if __name__ == "__main__":
    if len(sys.argv) != 3:
        print("사용법: python asdf1.py input.srt output.srt")
    else:
        input_srt_file = sys.argv[1]
        output_srt_file = sys.argv[2]
        add_sequence_numbers(input_srt_file, output_srt_file)